@@ -1,8 +1,8 @@
 from Fortuna import *
-from DungeonLib.cr import CR
-from DungeonLib.utilities import damage_types, cr_str
-from DungeonLib.treasure import Loot, get_loot, magic_table_f, magic_table_g, magic_table_h, magic_table_i, no_coin
-from DungeonLib.monsters_lib import motivation, random_monster, damage_type_cat
+from DungeonGenerator.cr import CR
+from DungeonGenerator.utilities import damage_types, cr_str
+from DungeonGenerator.treasure import Loot, get_loot, magic_table_f, magic_table_g, magic_table_h, magic_table_i, no_coin
+from DungeonGenerator.monsters_lib import motivation, random_monster, damage_type_cat
 
 
 class Monster:
