@@ -1,6 +1,6 @@
 from Fortuna import *
-from DungeonLib.utilities import cr_adapter
-from DungeonLib.spells import random_spell
+from DungeonGenerator.utilities import cr_adapter
+from DungeonGenerator.spells import random_spell
 
 
 def magic_table_by_cr(cr):
